@@ -1,10 +1,10 @@
 use strict;
 use warnings;
-package Test::JSON::Schema::Acceptance; # git description: v1.008-6-gc2d2241
+package Test::JSON::Schema::Acceptance; # git description: v1.009-4-ga74236d
 # vim: set ts=8 sts=2 sw=2 tw=100 et :
 # ABSTRACT: Acceptance testing for JSON-Schema based validators like JSON::Schema
 
-our $VERSION = '1.009';
+our $VERSION = '1.010';
 
 use 5.016;
 no if "$]" >= 5.031009, feature => 'indirect';
@@ -129,7 +129,7 @@ sub acceptance {
 
   my $ctx = Test2::API::context;
 
-  if ($options->{add_resource}) {
+  if ($options->{add_resource} and -d $self->additional_resources) {
     my $base = 'http://localhost:1234'; # TODO? make this customizable
     $ctx->note('adding resources from '.$self->additional_resources.' with the base URI "'.$base.'"...');
     $self->additional_resources->visit(
@@ -444,7 +444,7 @@ Test::JSON::Schema::Acceptance - Acceptance testing for JSON-Schema based valida
 
 =head1 VERSION
 
-version 1.009
+version 1.010
 
 =head1 SYNOPSIS
 
@@ -548,6 +548,10 @@ C<draft2020-12>
 
 C<latest> (alias for C<draft2020-12>)
 
+=item *
+
+C<draft-future>
+
 =back
 
 The default is C<latest>, but in the synopsis example, L<JSON::Schema> is testing draft 3
